<?php

namespace Drupal\alter_status_message\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for Alter Status Message module.
 */
class AlterStatusMessageConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'alter_status_message_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['alter_status_message.settings'];
  }

  /**
   * Build the configuration form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('alter_status_message.settings');

    $form['message_overrides'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message overrides'),
      '#description' => $this->t('Enter message overrides in the format: <br><em>original substring => replacement message</em><br>One per line. For example:<br>Created new user => 🎉 User created successfully!<br>Created user [name] => 🎉 User [name] successfully!<br>All caches cleared. => ✅ All caches have been cleared successfully! 🎉'),
      '#default_value' => $config->get('message_overrides') ?? '',
      '#rows' => 10,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Submit handler for the config form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('alter_status_message.settings')
      ->set('message_overrides', $form_state->getValue('message_overrides'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
